var searchData=
[
  ['jxlcolorencodingsettolinearsrgb_0',['JxlColorEncodingSetToLinearSRGB',['../group__libjxl__encoder.html#ga9eebcd8afdfb5a3f6e03e4043b8c8ab6',1,'encode.h']]],
  ['jxlcolorencodingsettosrgb_1',['JxlColorEncodingSetToSRGB',['../group__libjxl__encoder.html#ga496f5ead88a7ec0a0441eb2a2ebe1fa0',1,'encode.h']]],
  ['jxldecodercloseinput_2',['JxlDecoderCloseInput',['../group__libjxl__decoder.html#ga4d561b8ad80f53102924d684069b4dfa',1,'decode.h']]],
  ['jxldecodercreate_3',['JxlDecoderCreate',['../group__libjxl__decoder.html#ga7d6e767ab0bff9623a5d417b535ad0f3',1,'decode.h']]],
  ['jxldecoderdestroy_4',['JxlDecoderDestroy',['../group__libjxl__decoder.html#gae332fa7bcdd5c704781168aec7ad8031',1,'decode.h']]],
  ['jxldecoderextrachannelbuffersize_5',['JxlDecoderExtraChannelBufferSize',['../group__libjxl__decoder.html#ga97ae69e796e4261dd3211da899faf5b1',1,'decode.h']]],
  ['jxldecoderflushimage_6',['JxlDecoderFlushImage',['../group__libjxl__decoder.html#gadd9e27d914f11aae480ec60bd5500e47',1,'decode.h']]],
  ['jxldecodergetbasicinfo_7',['JxlDecoderGetBasicInfo',['../group__libjxl__decoder.html#gaccba9bc10b273d786af8d7262d5f38ee',1,'decode.h']]],
  ['jxldecodergetboxsizecontents_8',['JxlDecoderGetBoxSizeContents',['../group__libjxl__decoder.html#gab13073d6d4b81e8ec259206db7fbb66b',1,'decode.h']]],
  ['jxldecodergetboxsizeraw_9',['JxlDecoderGetBoxSizeRaw',['../group__libjxl__decoder.html#ga4b1566a3e2b9e9fa01caca88e012d3c7',1,'decode.h']]],
  ['jxldecodergetboxtype_10',['JxlDecoderGetBoxType',['../group__libjxl__decoder.html#gacc07c20f3a1d76ab5ff06475448518ec',1,'decode.h']]],
  ['jxldecodergetcolorasencodedprofile_11',['JxlDecoderGetColorAsEncodedProfile',['../group__libjxl__decoder.html#ga2ce841e245786683b26c915073acb021',1,'decode.h']]],
  ['jxldecodergetcolorasiccprofile_12',['JxlDecoderGetColorAsICCProfile',['../group__libjxl__decoder.html#ga92ad7a47347937afef418d00083b8c0b',1,'decode.h']]],
  ['jxldecodergetextrachannelblendinfo_13',['JxlDecoderGetExtraChannelBlendInfo',['../group__libjxl__decoder.html#gae070ba347a760d275e9521a394ff7ab0',1,'decode.h']]],
  ['jxldecodergetextrachannelinfo_14',['JxlDecoderGetExtraChannelInfo',['../group__libjxl__decoder.html#ga75fd17a8529536dff5b81ab6c76954a3',1,'decode.h']]],
  ['jxldecodergetextrachannelname_15',['JxlDecoderGetExtraChannelName',['../group__libjxl__decoder.html#ga3bbc9c3873d4deda80a3b87a1fd2b0cb',1,'decode.h']]],
  ['jxldecodergetframeheader_16',['JxlDecoderGetFrameHeader',['../group__libjxl__decoder.html#ga5148036be35a9e028764c8782e7754ff',1,'decode.h']]],
  ['jxldecodergetframename_17',['JxlDecoderGetFrameName',['../group__libjxl__decoder.html#ga3a7d764acba7f9fadd1e9577b95ca708',1,'decode.h']]],
  ['jxldecodergeticcprofilesize_18',['JxlDecoderGetICCProfileSize',['../group__libjxl__decoder.html#ga520306212b806e75367bc48e8000070d',1,'decode.h']]],
  ['jxldecodergetintendeddownsamplingratio_19',['JxlDecoderGetIntendedDownsamplingRatio',['../group__libjxl__decoder.html#ga6885a41ff9a2b9bd604129f90e50cc61',1,'decode.h']]],
  ['jxldecoderimageoutbuffersize_20',['JxlDecoderImageOutBufferSize',['../group__libjxl__decoder.html#ga692adb8fc41160b724fc97e0a78c3369',1,'decode.h']]],
  ['jxldecoderpreviewoutbuffersize_21',['JxlDecoderPreviewOutBufferSize',['../group__libjxl__decoder.html#ga14cb70d01114de42e0f40f2a1508869c',1,'decode.h']]],
  ['jxldecoderprocessinput_22',['JxlDecoderProcessInput',['../group__libjxl__decoder.html#gaafa003414866d15a0c13472b723831a1',1,'decode.h']]],
  ['jxldecoderreleaseboxbuffer_23',['JxlDecoderReleaseBoxBuffer',['../group__libjxl__decoder.html#ga001f5b19c31710338550ebd6b8888df6',1,'decode.h']]],
  ['jxldecoderreleaseinput_24',['JxlDecoderReleaseInput',['../group__libjxl__decoder.html#ga0c213b9a85d0cee4d67cf3f89d2e94dc',1,'decode.h']]],
  ['jxldecoderreleasejpegbuffer_25',['JxlDecoderReleaseJPEGBuffer',['../group__libjxl__decoder.html#ga7e90657bbd64b619228249f0e3ca093f',1,'decode.h']]],
  ['jxldecoderreset_26',['JxlDecoderReset',['../group__libjxl__decoder.html#gafdf297deaa45053b9f4242230795b78d',1,'decode.h']]],
  ['jxldecoderrewind_27',['JxlDecoderRewind',['../group__libjxl__decoder.html#ga27ebb80142a0e6e8383b25715b0c33a5',1,'decode.h']]],
  ['jxldecodersetboxbuffer_28',['JxlDecoderSetBoxBuffer',['../group__libjxl__decoder.html#gaa2706fc523f0e46450fcf09218e133a5',1,'decode.h']]],
  ['jxldecodersetcms_29',['JxlDecoderSetCms',['../group__libjxl__decoder.html#ga5ed345886a6333c62fbb1fb1c0f4b95c',1,'decode.h']]],
  ['jxldecodersetcoalescing_30',['JxlDecoderSetCoalescing',['../group__libjxl__decoder.html#ga3f5333a0a00d7c5b8dba5bb48d597ecc',1,'decode.h']]],
  ['jxldecodersetdecompressboxes_31',['JxlDecoderSetDecompressBoxes',['../group__libjxl__decoder.html#ga7bee3d9ed19ea43069dbdd65eab45f67',1,'decode.h']]],
  ['jxldecodersetdesiredintensitytarget_32',['JxlDecoderSetDesiredIntensityTarget',['../group__libjxl__decoder.html#ga341a46c46db79c691ff0caf92c313841',1,'decode.h']]],
  ['jxldecodersetextrachannelbuffer_33',['JxlDecoderSetExtraChannelBuffer',['../group__libjxl__decoder.html#gafdfb6ceae32287295a01bebfee02cf2b',1,'decode.h']]],
  ['jxldecodersetimageoutbitdepth_34',['JxlDecoderSetImageOutBitDepth',['../group__libjxl__decoder.html#ga1b9933670ae58f1c72f604552e1069d7',1,'decode.h']]],
  ['jxldecodersetimageoutbuffer_35',['JxlDecoderSetImageOutBuffer',['../group__libjxl__decoder.html#ga604ca7b949c0e5e91edb5ef60c79804c',1,'decode.h']]],
  ['jxldecodersetimageoutcallback_36',['JxlDecoderSetImageOutCallback',['../group__libjxl__decoder.html#gac2f15d8152ae8b0ec7620ee7b71cfd33',1,'decode.h']]],
  ['jxldecodersetinput_37',['JxlDecoderSetInput',['../group__libjxl__decoder.html#ga407f817f4bb09f55bb17d1205e4b0c83',1,'decode.h']]],
  ['jxldecodersetjpegbuffer_38',['JxlDecoderSetJPEGBuffer',['../group__libjxl__decoder.html#gae083249628e3b1aa5146b3e34bdda290',1,'decode.h']]],
  ['jxldecodersetkeeporientation_39',['JxlDecoderSetKeepOrientation',['../group__libjxl__decoder.html#gad378afe4ec724497f84d7d42acc6be8c',1,'decode.h']]],
  ['jxldecodersetmultithreadedimageoutcallback_40',['JxlDecoderSetMultithreadedImageOutCallback',['../group__libjxl__decoder.html#ga2a85285227e9619371d5406cbacacb9f',1,'decode.h']]],
  ['jxldecodersetoutputcolorprofile_41',['JxlDecoderSetOutputColorProfile',['../group__libjxl__decoder.html#ga07be5f66464fcc2283dc7a08341c5fbf',1,'decode.h']]],
  ['jxldecodersetparallelrunner_42',['JxlDecoderSetParallelRunner',['../group__libjxl__decoder.html#gaaf1e26569b3830834ed05728486a51a3',1,'decode.h']]],
  ['jxldecodersetpreferredcolorprofile_43',['JxlDecoderSetPreferredColorProfile',['../group__libjxl__decoder.html#gabc5912d2180c6121f2fbd2b1b58d5931',1,'decode.h']]],
  ['jxldecodersetpreviewoutbuffer_44',['JxlDecoderSetPreviewOutBuffer',['../group__libjxl__decoder.html#ga3a64ed8f22f5d21aa04a0c4549001b51',1,'decode.h']]],
  ['jxldecodersetprogressivedetail_45',['JxlDecoderSetProgressiveDetail',['../group__libjxl__decoder.html#gaed4c3ed790bd9b1646a35c136c80d6b2',1,'decode.h']]],
  ['jxldecodersetrenderspotcolors_46',['JxlDecoderSetRenderSpotcolors',['../group__libjxl__decoder.html#gafc3a3d747bc8010b9a11fc4e2c9a0b41',1,'decode.h']]],
  ['jxldecodersetunpremultiplyalpha_47',['JxlDecoderSetUnpremultiplyAlpha',['../group__libjxl__decoder.html#gaccf5cf97e6f8d1a3f36b2775f3ac4425',1,'decode.h']]],
  ['jxldecodersizehintbasicinfo_48',['JxlDecoderSizeHintBasicInfo',['../group__libjxl__decoder.html#ga55d164c7cd6c6b0e4a1482bc064403b4',1,'decode.h']]],
  ['jxldecoderskipcurrentframe_49',['JxlDecoderSkipCurrentFrame',['../group__libjxl__decoder.html#ga7a70d09994483b88ecabb51e92072267',1,'decode.h']]],
  ['jxldecoderskipframes_50',['JxlDecoderSkipFrames',['../group__libjxl__decoder.html#ga00ee033a14ada3fc651cdcf2668167d8',1,'decode.h']]],
  ['jxldecodersubscribeevents_51',['JxlDecoderSubscribeEvents',['../group__libjxl__decoder.html#gaacca63a647f34142f0df969654a900e5',1,'decode.h']]],
  ['jxldecoderversion_52',['JxlDecoderVersion',['../group__libjxl__decoder.html#ga05a5a60ec844b5ad37ceba3fcea5c9aa',1,'decode.h']]],
  ['jxlencoderaddbox_53',['JxlEncoderAddBox',['../group__libjxl__encoder.html#gae294d25bafc4de045f8b11c668e25a4f',1,'encode.h']]],
  ['jxlencoderaddchunkedframe_54',['JxlEncoderAddChunkedFrame',['../group__libjxl__encoder.html#gaff9ee8ebd30ab964d37e0770c85ad9e7',1,'encode.h']]],
  ['jxlencoderaddimageframe_55',['JxlEncoderAddImageFrame',['../group__libjxl__encoder.html#gab310a840a57cd0ff9518620becfe1a79',1,'encode.h']]],
  ['jxlencoderaddjpegframe_56',['JxlEncoderAddJPEGFrame',['../group__libjxl__encoder.html#ga09abfec1abc543ff85e9c999e8de22c1',1,'encode.h']]],
  ['jxlencoderallowexpertoptions_57',['JxlEncoderAllowExpertOptions',['../group__libjxl__encoder.html#ga99009fa26db477cbe7d52b3dbe636427',1,'encode.h']]],
  ['jxlencodercloseboxes_58',['JxlEncoderCloseBoxes',['../group__libjxl__encoder.html#ga94784eb8ae642483dfd343a77b496963',1,'encode.h']]],
  ['jxlencodercloseframes_59',['JxlEncoderCloseFrames',['../group__libjxl__encoder.html#gaae65f5dc77b7868a0c4fff594a70587b',1,'encode.h']]],
  ['jxlencodercloseinput_60',['JxlEncoderCloseInput',['../group__libjxl__encoder.html#ga15c2d57b243e216bf722817e974ad99a',1,'encode.h']]],
  ['jxlencodercollectstats_61',['JxlEncoderCollectStats',['../group__libjxl__encoder.html#ga20a05a277441b4fd4c5584a5b9fdd370',1,'encode.h']]],
  ['jxlencodercreate_62',['JxlEncoderCreate',['../group__libjxl__encoder.html#ga3362131f5c8f61e35cabad9882a2d8d7',1,'encode.h']]],
  ['jxlencoderdestroy_63',['JxlEncoderDestroy',['../group__libjxl__encoder.html#gaf2ca073390dd02b0211559a206ddc7fd',1,'encode.h']]],
  ['jxlencoderdistancefromquality_64',['JxlEncoderDistanceFromQuality',['../group__libjxl__encoder.html#ga58761fc801812e44962476a3bef41ce8',1,'encode.h']]],
  ['jxlencoderflushinput_65',['JxlEncoderFlushInput',['../group__libjxl__encoder.html#gae541a1fec38cb3a9ffb7b9acee1dff45',1,'encode.h']]],
  ['jxlencoderframesettingscreate_66',['JxlEncoderFrameSettingsCreate',['../group__libjxl__encoder.html#gacd3be8bf29957b9b129bfa60a3e359c3',1,'encode.h']]],
  ['jxlencoderframesettingssetfloatoption_67',['JxlEncoderFrameSettingsSetFloatOption',['../group__libjxl__encoder.html#ga62dc420b739b96d55cc9462ae0128831',1,'encode.h']]],
  ['jxlencoderframesettingssetoption_68',['JxlEncoderFrameSettingsSetOption',['../group__libjxl__encoder.html#ga250ff79feafd39eebd4dab42cf854cc2',1,'encode.h']]],
  ['jxlencodergeterror_69',['JxlEncoderGetError',['../group__libjxl__encoder.html#gad3cab4169e526fd87a92c1c5f21791c0',1,'encode.h']]],
  ['jxlencodergetrequiredcodestreamlevel_70',['JxlEncoderGetRequiredCodestreamLevel',['../group__libjxl__encoder.html#ga02c330f04231a2c57e3e3e8b51328ae0',1,'encode.h']]],
  ['jxlencoderinitbasicinfo_71',['JxlEncoderInitBasicInfo',['../group__libjxl__encoder.html#ga7027799801b8a7c1266899c6bef2d18a',1,'encode.h']]],
  ['jxlencoderinitblendinfo_72',['JxlEncoderInitBlendInfo',['../group__libjxl__encoder.html#ga15aab07fb1cc8ed5185938a066c971e8',1,'encode.h']]],
  ['jxlencoderinitextrachannelinfo_73',['JxlEncoderInitExtraChannelInfo',['../group__libjxl__encoder.html#gaad8fa32172959f36a152c01e2d43c189',1,'encode.h']]],
  ['jxlencoderinitframeheader_74',['JxlEncoderInitFrameHeader',['../group__libjxl__encoder.html#ga4d31572dc7f196d6b634de7abbd794f8',1,'encode.h']]],
  ['jxlencoderprocessoutput_75',['JxlEncoderProcessOutput',['../group__libjxl__encoder.html#ga38c90ac1ff7a2ead7efe2e84054a5a63',1,'encode.h']]],
  ['jxlencoderreset_76',['JxlEncoderReset',['../group__libjxl__encoder.html#ga58b8bf934ad27f58c2f1d966e8dd70b6',1,'encode.h']]],
  ['jxlencodersetbasicinfo_77',['JxlEncoderSetBasicInfo',['../group__libjxl__encoder.html#ga7fd2ff5b0f8d43791be94f46314764b5',1,'encode.h']]],
  ['jxlencodersetcms_78',['JxlEncoderSetCms',['../group__libjxl__encoder.html#ga4bfd584ec4c9735e652fc494d6315f47',1,'encode.h']]],
  ['jxlencodersetcodestreamlevel_79',['JxlEncoderSetCodestreamLevel',['../group__libjxl__encoder.html#ga042290cea6c56afd5cd043c53a38338d',1,'encode.h']]],
  ['jxlencodersetcolorencoding_80',['JxlEncoderSetColorEncoding',['../group__libjxl__encoder.html#ga881d3c48e12962d68ad5d1a8dc01c56d',1,'encode.h']]],
  ['jxlencodersetdebugimagecallback_81',['JxlEncoderSetDebugImageCallback',['../group__libjxl__encoder.html#gabe834d4ec36972d6b50af9cedf7a50a4',1,'encode.h']]],
  ['jxlencodersetextrachannelblendinfo_82',['JxlEncoderSetExtraChannelBlendInfo',['../group__libjxl__encoder.html#ga9097651ece7df5d97401d9c6cf12319b',1,'encode.h']]],
  ['jxlencodersetextrachannelbuffer_83',['JxlEncoderSetExtraChannelBuffer',['../group__libjxl__encoder.html#ga3775e029431f4fea26c2281b35f850d0',1,'encode.h']]],
  ['jxlencodersetextrachanneldistance_84',['JxlEncoderSetExtraChannelDistance',['../group__libjxl__encoder.html#gaae191af0abb36509345edcf31ed7b393',1,'encode.h']]],
  ['jxlencodersetextrachannelinfo_85',['JxlEncoderSetExtraChannelInfo',['../group__libjxl__encoder.html#gaf8fc6b9215fd2c657c237b71dca13972',1,'encode.h']]],
  ['jxlencodersetextrachannelname_86',['JxlEncoderSetExtraChannelName',['../group__libjxl__encoder.html#gad90c2b8ba04ac166adf9162e6f306f6a',1,'encode.h']]],
  ['jxlencodersetframebitdepth_87',['JxlEncoderSetFrameBitDepth',['../group__libjxl__encoder.html#ga4cde08ba6a7eb163525045de109a3de2',1,'encode.h']]],
  ['jxlencodersetframedistance_88',['JxlEncoderSetFrameDistance',['../group__libjxl__encoder.html#ga94e14ada15eb10ab757ee8cb192c0497',1,'encode.h']]],
  ['jxlencodersetframeheader_89',['JxlEncoderSetFrameHeader',['../group__libjxl__encoder.html#ga9d28b52a68e04d182f5525f299fd6839',1,'encode.h']]],
  ['jxlencodersetframelossless_90',['JxlEncoderSetFrameLossless',['../group__libjxl__encoder.html#ga5ec563937d10be0b0f64888e4e7d06bf',1,'encode.h']]],
  ['jxlencodersetframename_91',['JxlEncoderSetFrameName',['../group__libjxl__encoder.html#gabc9742f22cbe2d8b10f3f0a78dccf271',1,'encode.h']]],
  ['jxlencoderseticcprofile_92',['JxlEncoderSetICCProfile',['../group__libjxl__encoder.html#gab3e4a073ba54153936d2c2105f09d06d',1,'encode.h']]],
  ['jxlencodersetoutputprocessor_93',['JxlEncoderSetOutputProcessor',['../group__libjxl__encoder.html#ga6af9246aa41df6acabcbd9d9967f6ea9',1,'encode.h']]],
  ['jxlencodersetparallelrunner_94',['JxlEncoderSetParallelRunner',['../group__libjxl__encoder.html#ga19c19a11a728e19c290b6165cc768b39',1,'encode.h']]],
  ['jxlencodersetupsamplingmode_95',['JxlEncoderSetUpsamplingMode',['../group__libjxl__encoder.html#ga96fe48f6b4cd4c5cedbca2cebf621798',1,'encode.h']]],
  ['jxlencoderstatscreate_96',['JxlEncoderStatsCreate',['../group__libjxl__encoder.html#ga5c3726fc550b31c2ceafb07b7349ee0a',1,'stats.h']]],
  ['jxlencoderstatsdestroy_97',['JxlEncoderStatsDestroy',['../group__libjxl__encoder.html#gac902660d5bb304b6b092013e97d7af94',1,'stats.h']]],
  ['jxlencoderstatsget_98',['JxlEncoderStatsGet',['../group__libjxl__encoder.html#ga0dde7b3bf317c918d7fe72fd2f2a597c',1,'stats.h']]],
  ['jxlencoderstatsmerge_99',['JxlEncoderStatsMerge',['../group__libjxl__encoder.html#ga9c0a1a723000226b510f333ced51ed57',1,'stats.h']]],
  ['jxlencoderstorejpegmetadata_100',['JxlEncoderStoreJPEGMetadata',['../group__libjxl__encoder.html#gafac566d8a87e395d95655e552418f9ae',1,'encode.h']]],
  ['jxlencoderuseboxes_101',['JxlEncoderUseBoxes',['../group__libjxl__encoder.html#ga667dae9b3d39cc1c859db1dddae47555',1,'encode.h']]],
  ['jxlencoderusecontainer_102',['JxlEncoderUseContainer',['../group__libjxl__encoder.html#ga3fbb30200bb9b55a550c01015f2bcb9c',1,'encode.h']]],
  ['jxlencoderversion_103',['JxlEncoderVersion',['../group__libjxl__encoder.html#gac2bc1706762bbd1c40fd06a41222156d',1,'encode.h']]],
  ['jxlgainmapgetbundlesize_104',['JxlGainMapGetBundleSize',['../group__libjxl__metadata.html#ga546a732f9f5891f66e7d72c62b6c118a',1,'gain_map.h']]],
  ['jxlgainmapreadbundle_105',['JxlGainMapReadBundle',['../group__libjxl__metadata.html#ga69ce70bafe565a9bdfe7459e9727a19a',1,'gain_map.h']]],
  ['jxlgainmapwritebundle_106',['JxlGainMapWriteBundle',['../group__libjxl__metadata.html#ga6843276a0ab8a7220e0a9ce1dc529213',1,'gain_map.h']]],
  ['jxliccprofiledecode_107',['JxlICCProfileDecode',['../group__libjxl__metadata.html#ga0887d437a6f55ecb90937c7dfeb4b467',1,'compressed_icc.h']]],
  ['jxliccprofileencode_108',['JxlICCProfileEncode',['../group__libjxl__metadata.html#ga81a828eb0538943000d66a5b6ebdf848',1,'compressed_icc.h']]],
  ['jxlresizableparallelrunner_109',['JxlResizableParallelRunner',['../group__libjxl__threads.html#gad7cad7f1de97ddcd3868c678691365d5',1,'resizable_parallel_runner.h']]],
  ['jxlresizableparallelrunnercreate_110',['JxlResizableParallelRunnerCreate',['../group__libjxl__threads.html#ga98a744fddf24168ff3efa7c10b8700a9',1,'resizable_parallel_runner.h']]],
  ['jxlresizableparallelrunnerdestroy_111',['JxlResizableParallelRunnerDestroy',['../group__libjxl__threads.html#ga7f4055b9996895389107932ea17e2598',1,'resizable_parallel_runner.h']]],
  ['jxlresizableparallelrunnersetthreads_112',['JxlResizableParallelRunnerSetThreads',['../group__libjxl__threads.html#gad9c22a8767f8ef655e997c5670436fc5',1,'resizable_parallel_runner.h']]],
  ['jxlresizableparallelrunnersuggestthreads_113',['JxlResizableParallelRunnerSuggestThreads',['../group__libjxl__threads.html#gaa1c8b31a87c02d5d17f420b23d12d27b',1,'resizable_parallel_runner.h']]],
  ['jxlsignaturecheck_114',['JxlSignatureCheck',['../group__libjxl__decoder.html#gae7c12395ee08066995b03efde8c3ba0d',1,'decode.h']]],
  ['jxlthreadparallelrunner_115',['JxlThreadParallelRunner',['../group__libjxl__threads.html#ga37e181cb285bda4fb2978d035e58ff87',1,'thread_parallel_runner.h']]],
  ['jxlthreadparallelrunnercreate_116',['JxlThreadParallelRunnerCreate',['../group__libjxl__threads.html#ga75346d2249a525594bb133c5e1b3cf8a',1,'thread_parallel_runner.h']]],
  ['jxlthreadparallelrunnerdefaultnumworkerthreads_117',['JxlThreadParallelRunnerDefaultNumWorkerThreads',['../group__libjxl__threads.html#ga1705fa654dacb8b13d544628d702c31e',1,'thread_parallel_runner.h']]],
  ['jxlthreadparallelrunnerdestroy_118',['JxlThreadParallelRunnerDestroy',['../group__libjxl__threads.html#ga8c782b85f63c04956637e100dd82ccdb',1,'thread_parallel_runner.h']]]
];
